@@ -2,11 +2,11 @@
 #ifndef GETCODE_H
 #define GETCODE_H
 
-/* $Id: getcode.h,v 1.5 2005/09/28 13:17:06 hio Exp $ */
+/* $Id: getcode.h,v 1.6 2006/06/26 05:41:21 hio Exp $ */
 
 #ifdef TEST
 #define DECL_MAP_MODE(name,num) const char* mode_##name[num]
-#define EXTERN_DECL_MAP_MODE(name,num) extern DECL_MAP_MODE(name,num)
+#define EXTERN_DECL_MAP_MODE(name,num) extern DECL_MAP_MODE(name,num);
 #else
 #define DECL_MAP_MODE(name,num)
 #define EXTERN_DECL_MAP_MODE(name,num)
@@ -16,7 +16,7 @@
   extern const unsigned char map_##name[num][256]
 
 #define DECL_MAP(name,num) DECL_MAP_MODE(name,num); DECL_MAP_TABLE(name,num)
-#define EXTERN_DECL_MAP(name,num) EXTERN_DECL_MAP_MODE(name,num); DECL_MAP_TABLE(name,num)
+#define EXTERN_DECL_MAP(name,num) EXTERN_DECL_MAP_MODE(name,num) DECL_MAP_TABLE(name,num)
 
 EXTERN_DECL_MAP(ascii,1);
 EXTERN_DECL_MAP(eucjp,5);
